==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieUprawnienia.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZlecenieUprawnienia extends GenericDPSObject {
    /**
     * ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodTytuluUpr;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodTytuluUprDod;

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kod;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodZam1;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodZam2;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodZam3;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodTytuluUpr() {
        return kodTytuluUpr;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     *
     * @param kodTytuluUpr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodTytuluUpr(String kodTytuluUpr) {
        this.kodTytuluUpr = kodTytuluUpr == null ? null : kodTytuluUpr.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodTytuluUprDod() {
        return kodTytuluUprDod;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     *
     * @param kodTytuluUprDod
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodTytuluUprDod(String kodTytuluUprDod) {
        this.kodTytuluUprDod = kodTytuluUprDod == null ? null : kodTytuluUprDod.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKod() {
        return kod;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodZam1() {
        return kodZam1;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     *
     * @param kodZam1
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodZam1(String kodZam1) {
        this.kodZam1 = kodZam1 == null ? null : kodZam1.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodZam2() {
        return kodZam2;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     *
     * @param kodZam2
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodZam2(String kodZam2) {
        this.kodZam2 = kodZam2 == null ? null : kodZam2.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodZam3() {
        return kodZam3;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     *
     * @param kodZam3
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodZam3(String kodZam3) {
        this.kodZam3 = kodZam3 == null ? null : kodZam3.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieUprawnienia other = (ZlecenieUprawnienia) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getKodTytuluUpr() == null ? other.getKodTytuluUpr() == null : this.getKodTytuluUpr().equals(other.getKodTytuluUpr()))
            && (this.getKodTytuluUprDod() == null ? other.getKodTytuluUprDod() == null : this.getKodTytuluUprDod().equals(other.getKodTytuluUprDod()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getKodZam1() == null ? other.getKodZam1() == null : this.getKodZam1().equals(other.getKodZam1()))
            && (this.getKodZam2() == null ? other.getKodZam2() == null : this.getKodZam2().equals(other.getKodZam2()))
            && (this.getKodZam3() == null ? other.getKodZam3() == null : this.getKodZam3().equals(other.getKodZam3()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getKodTytuluUpr() == null) ? 0 : getKodTytuluUpr().hashCode());
        result = prime * result + ((getKodTytuluUprDod() == null) ? 0 : getKodTytuluUprDod().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getKodZam1() == null) ? 0 : getKodZam1().hashCode());
        result = prime * result + ((getKodZam2() == null) ? 0 : getKodZam2().hashCode());
        result = prime * result + ((getKodZam3() == null) ? 0 : getKodZam3().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", kodTytuluUpr=").append(kodTytuluUpr);
        sb.append(", kodTytuluUprDod=").append(kodTytuluUprDod);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kod=").append(kod);
        sb.append(", kodZam1=").append(kodZam1);
        sb.append(", kodZam2=").append(kodZam2);
        sb.append(", kodZam3=").append(kodZam3);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieUprawnienia.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZlecenieUprawnienia extends GenericDPSObject {
    /**
     * ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodTytuluUpr;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodTytuluUprDod;

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kod;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodZam1;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodZam2;

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodZam3;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodTytuluUpr() {
        return kodTytuluUpr;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR
     *
     * @param kodTytuluUpr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodTytuluUpr(String kodTytuluUpr) {
        this.kodTytuluUpr = kodTytuluUpr == null ? null : kodTytuluUpr.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodTytuluUprDod() {
        return kodTytuluUprDod;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_TYTULU_UPR_DOD
     *
     * @param kodTytuluUprDod
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodTytuluUprDod(String kodTytuluUprDod) {
        this.kodTytuluUprDod = kodTytuluUprDod == null ? null : kodTytuluUprDod.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKod() {
        return kod;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD
     *
     * @param kod
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKod(String kod) {
        this.kod = kod == null ? null : kod.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodZam1() {
        return kodZam1;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_1
     *
     * @param kodZam1
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodZam1(String kodZam1) {
        this.kodZam1 = kodZam1 == null ? null : kodZam1.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodZam2() {
        return kodZam2;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_2
     *
     * @param kodZam2
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodZam2(String kodZam2) {
        this.kodZam2 = kodZam2 == null ? null : kodZam2.trim();
    }

    /**
     * @return ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodZam3() {
        return kodZam3;
    }

    /**
     * ZLECENIE_UPRAWNIENIA.KOD_ZAM_3
     *
     * @param kodZam3
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodZam3(String kodZam3) {
        this.kodZam3 = kodZam3 == null ? null : kodZam3.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieUprawnienia other = (ZlecenieUprawnienia) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getKodTytuluUpr() == null ? other.getKodTytuluUpr() == null : this.getKodTytuluUpr().equals(other.getKodTytuluUpr()))
            && (this.getKodTytuluUprDod() == null ? other.getKodTytuluUprDod() == null : this.getKodTytuluUprDod().equals(other.getKodTytuluUprDod()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKod() == null ? other.getKod() == null : this.getKod().equals(other.getKod()))
            && (this.getKodZam1() == null ? other.getKodZam1() == null : this.getKodZam1().equals(other.getKodZam1()))
            && (this.getKodZam2() == null ? other.getKodZam2() == null : this.getKodZam2().equals(other.getKodZam2()))
            && (this.getKodZam3() == null ? other.getKodZam3() == null : this.getKodZam3().equals(other.getKodZam3()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getKodTytuluUpr() == null) ? 0 : getKodTytuluUpr().hashCode());
        result = prime * result + ((getKodTytuluUprDod() == null) ? 0 : getKodTytuluUprDod().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKod() == null) ? 0 : getKod().hashCode());
        result = prime * result + ((getKodZam1() == null) ? 0 : getKodZam1().hashCode());
        result = prime * result + ((getKodZam2() == null) ? 0 : getKodZam2().hashCode());
        result = prime * result + ((getKodZam3() == null) ? 0 : getKodZam3().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", kodTytuluUpr=").append(kodTytuluUpr);
        sb.append(", kodTytuluUprDod=").append(kodTytuluUprDod);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kod=").append(kod);
        sb.append(", kodZam1=").append(kodZam1);
        sb.append(", kodZam2=").append(kodZam2);
        sb.append(", kodZam3=").append(kodZam3);
        sb.append("]");
        return sb.toString();
    }
}
